function  [dataDesc,dataFixed]  = pnDataDescriptions()
%PNDATADESCRIPTIONS	Output data descriptions
%	 dataDesc  = pnDataDescriptions() outputs a cell array which matches
%	data abbreviations and their corresponding descriptions
%
%	Outputs:
%		dataDesc    - Cell array containing abbreviations (column 1) and
%		descriptions (column 2)
%	
%	See also PNSUBSAMPLEDATA

%	References:
%       Physionet Challenge 2012
%       http://physionet.org/challenge/2012/

%	Copyright 2012 Alistair Johnson

%	$LastChangedBy: alistair $
%	$LastChangedDate: 2012-05-29 09:01:11 -0400 (Tue, 29 May 2012) $
%	$Revision: 1 $
%	Originally written on GLNXA64 by Alistair Johnson, 25-Jan-2012 19:13:43
%	Contact: alistairewj@gmail.com


%=== Create columns for all the features which change temporally
dataDesc = {'Albumin', 'Serum Albumin (g/dL)';...
    'ALP', 'Alkaline phosphatase (IU/L)';...
    'ALT', 'Alanine transaminase (IU/L)';...
    'AST', 'Aspartate transaminase (IU/L)';...
    'Bilirubin', 'Bilirubin (mg/dL)';...
    'BUN', 'Blood urea nitrogen (mg/dL)';...
    'Cholesterol', 'Cholesterol (mg/dL)';...
    'Creatinine', 'Serum creatinine (mg/dL)';...
    'DiasABP', 'Invasive diastolic arterial blood pressure (mmHg)';...
    'FiO2', 'Fractional inspired O2 (0-1)';...
    'GCS', 'Glasgow Coma Score (3-15)';...
    'Glucose', 'Serum glucose (mg/dL)';...
    'HCO3', 'Serum bicarbonate (mmol/L)';...
    'HCT', 'Hematocrit (%)';...
    'HR', 'Heart rate (bpm)';...
    'K', 'Serum potassium (mEq/L)';...
    'Lactate', 'Lactate (mmol/L)';...
    'Mg', 'Serum magnesium (mmol/L)';...
    'MAP', 'Invasive mean arterial blood pressure (mmHg)';...
    'MechVent', 'Mechanical ventilation respiration (0:false, or 1:true)';...
    'Na', 'Serum sodium (mEq/L)';...
    'NIDiasABP', 'Non-invasive diastolic arterial blood pressure (mmHg)';...
    'NIMAP', 'Non-invasive mean arterial blood pressure (mmHg)';...
    'NISysABP', 'Non-invasive systolic arterial blood pressure (mmHg)';...
    'PaCO2', 'partial pressure of arterial CO2 (mmHg)';...
    'PaO2', 'Partial pressure of arterial O2 (mmHg)';...
    'pH', 'Arterial pH (0-14)';...
    'Platelets', 'Platelets (cells/nL)';...
    'RespRate', 'Respiration rate (bpm)';...
    'SaO2', 'O2 saturation in hemoglobin (%)';...
    'SysABP', 'Invasive systolic arterial blood pressure (mmHg)';...
    'Temp', 'Temperature (°C)';...
    'TroponinI', 'Troponin-I (μg/L)';...
    'TroponinT', 'Troponin-T (μg/L)';...
    'Urine', 'Urine output (mL)';...
    'WBC', 'White blood cell count (cells/nL)';...
    'Weight', 'Weight (kg)'};

%=== Create cell array for values which do not change temporally
dataFixed = {'RecordID', 'Record ID specifying patient';...
'Age','Age (yrs)';...
'Gender', 'Gender (female = true)';...
'Height', 'Height (cm)'}; 
    
end